from __future__ import annotations

from gui_qt.Qt import QtWidgets, QtCore
from gui_qt._py.guidelinewidget import Ui_Form
from gui_qt.graphs.draw_inputs import EllipseWidget, LineWidget, MultiPointWidget, RectangleWidget, TextWidget
from gui_qt.graphs.draw_objects import LineObject, MultipointObject


class DrawingsWidget(QtWidgets.QWidget, Ui_Form):

    def __init__(self, parent=None):
        super().__init__(parent=parent)

        self.setupUi(self)

        self.widgets = [LineWidget(self), MultiPointWidget(self), TextWidget(self), RectangleWidget(self), EllipseWidget(self)]
        for w in self.widgets:
            self.stackedWidget.addWidget(w)

        self.graphs = None

    def update_tree(self):
        for gid, windows in self.graphs.items():
            item = QtWidgets.QTreeWidgetItem([windows.title])
            item.setData(0, QtCore.Qt.UserRole, gid)

            for d in windows.drawings.values():
                child = QtWidgets.QTreeWidgetItem([d])
                item.addChild(child)

            self.treeWidget_2.addTopLevelItem(item)
            # self.graph_comboBox.addItem(name, userData=gid)

    def clear(self):
        self.graph_comboBox.clear()

    @QtCore.pyqtSlot(int, name='on_mode_comboBox_currentIndexChanged')
    def change_draw_type(self, idx: int):
        self.stackedWidget.setCurrentIndex(idx)

    @QtCore.pyqtSlot(name='on_pushButton_3_clicked')
    def make_drawing(self):
        dic = self.stackedWidget.currentWidget().collect_args()
        if dic is None:
            QtWidgets.QMessageBox.information(self, 'Not working', 'Something is missing to create this object')
            return
        idx = self.treeWidget_2.selectedIndexes()
        if idx:
            item = self.treeWidget_2.itemFromIndex(idx[0])
            graph_id = item.data(0, QtCore.Qt.UserRole)
            if self.mode_comboBox.currentIndex() == 0:
                new_obj = LineObject(**dic)
            elif self.mode_comboBox.currentIndex() == 1:
                new_obj = MultipointObject(**dic)
            child = QtWidgets.QTreeWidgetItem([str(new_obj)])
            child.setData(0, QtCore.Qt.UserRole, new_obj.id)
            item.addChild(child)

            self.graphs[graph_id].addDrawing(new_obj)
        else:
            QtWidgets.QMessageBox.information(self, 'Not working', 'No graph is selected to add this object.')

        self.treeWidget_2.expandAll()


if __name__ == '__main__':
    app = QtWidgets.QApplication([])
    w = DrawingsWidget()
    w.show()
    app.exec()
